@@ -12,7 +12,7 @@ from openai import OpenAI
 from typing_extensions import Any, Protocol
 
 from patchwork.logger import logger
-from patchwork.step import Step
+from patchwork.step import Step, StepStatus
 
 TOKEN_URL = "https://app.patched.codes/signin"
 _DEFAULT_PATCH_URL = "https://patchwork.patched.codes/v1"
@@ -158,8 +158,7 @@ class CallOpenAI(LLMModel):
 
 class CallLLM(Step):
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         # Set 'openai_key' from inputs or environment if not already set
         inputs.setdefault("openai_api_key", os.environ.get("OPENAI_API_KEY"))
 
@@ -178,7 +177,7 @@ class CallLLM(Step):
         else:
             raise ValueError('Missing required data: "prompt_file" or "prompts"')
 
-        self.call_limit = int(inputs.get("max_llm_calls", 50))
+        self.call_limit = int(inputs.get("max_llm_calls", -1))
         self.model_args = {key[len("model_") :]: value for key, value in inputs.items() if key.startswith("model_")}
         self.client_args = {key[len("client_") :]: value for key, value in inputs.items() if key.startswith("client_")}
         self.save_responses_to_file = inputs.get("save_responses_to_file", None)
@@ -223,13 +222,20 @@ class CallLLM(Step):
 
     def run(self) -> dict:
         prompt_length = len(self.prompts)
-        if prompt_length > self.call_limit:
+        if prompt_length == 0:
+            self.set_status(StepStatus.SKIPPED, "No prompts to process")
+            return dict(openai_responses=[])
+
+        if -1 < self.call_limit < prompt_length:
             logger.debug(
                 f"Number of prompts ({prompt_length}) exceeds the call limit ({self.call_limit}). "
                 f"Only the first {self.call_limit} prompts will be processed."
             )
+            prompts = list(islice(self.prompts, self.call_limit))
+        else:
+            prompts = self.prompts
 
-        contents = self.llm.call(list(islice(self.prompts, self.call_limit)))
+        contents = self.llm.call(prompts)
 
         if self.save_responses_to_file:
             # Convert relative path to absolute path
@@ -247,5 +253,4 @@ class CallLLM(Step):
                     }
                     f.write(json.dumps(data) + "\n")
 
-        logger.info(f"Run completed {self.__class__.__name__}")
         return dict(openai_responses=contents)
